==> canine.db_2.2.5.tar.gz: canine.db/man/canine_dbconn.Rd <==
\name{canine_dbconn}

\alias{canine_dbconn}
\alias{canine_dbfile}
\alias{canine_dbschema}
\alias{canine_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  canine_dbconn()
  canine_dbfile()
  canine_dbschema(file="", show.indices=FALSE)
  canine_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{canine_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{canine_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{canine_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{canine_dbschema} prints the schema definition of the
  package annotation DB.

  \code{canine_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{canine_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{canine_dbfile}: a character string with the path to the
  package annotation DB.

  \code{canine_dbschema}: none (invisible \code{NULL}).

  \code{canine_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(canine_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by canine_dbconn() was created with:
  dbConnect(SQLite(), dbname=canine_dbfile(), cache_size=64000, synchronous=0)

  canine_dbschema()

  canine_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> canine.db_2.8.1.tar.gz: canine.db/man/canine_dbconn.Rd <==

\name{canine_dbconn}

\alias{canine_dbconn}
\alias{canine_dbfile}
\alias{canine_dbschema}
\alias{canine_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  canine_dbconn()
  canine_dbfile()
  canine_dbschema(file="", show.indices=FALSE)
  canine_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{canine_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{canine_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{canine_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{canine_dbschema} prints the schema definition of the
  package annotation DB.

  \code{canine_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{canine_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{canine_dbfile}: a character string with the path to the
  package annotation DB.

  \code{canine_dbschema}: none (invisible \code{NULL}).

  \code{canine_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(canine_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by canine_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=canine_dbfile(), cache_size=64000,
  synchronous=0)

  canine_dbschema()

  canine_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
